
using ElasticSearchStudy.Core;

namespace ElasticSearchStudy.UnitTest
{
    public class UseElasticSearchTest
    {
        private readonly ITestOutputHelper _output;
        private readonly ElasticsearchClient _client;

        public UseElasticSearchTest(ITestOutputHelper outputHelper)
        {
            _output = outputHelper;

            var elasticSetting = new ElasticsearchClientSettings(new Uri("https://127.0.0.1:9201"))
                .CertificateFingerprint("e57ce099af49fb34742cddffe1271c4ed709ef29649537fe89e6bee32728444d")
                .Authentication(new BasicAuthentication("elastic", "es-461400"));

            _client = new ElasticsearchClient(elasticSetting);
        }

        /// <summary>
        /// ESҳ
        /// </summary>
        [Fact]
        public void Ping_Test()
        {
            var pingResponse = _client.Ping();

            if (pingResponse.IsSuccess())
            {
                _output.WriteLine($"ɹ,{pingResponse.DebugInformation}");
            }
            else
            {
                _output.WriteLine("ʧ");
            }

            Assert.True(pingResponse.IsSuccess());
        }

        /// <summary>
        /// ȺϢ
        /// </summary>
        [Fact]
        public void Health_Test()
        {
            var response =  _client.Cluster.Health();

            Assert.True(response.IsSuccess());

            //Ϣ
            _output.WriteLine($"Ⱥƣ{response.ClusterName}");
            _output.WriteLine($"Ⱥ״̬{response.Status}");
            _output.WriteLine($"ڵ{response.NumberOfNodes}");
            _output.WriteLine($"ݽڵ㣺{response.NumberOfNodes}");
            _output.WriteLine($"{response.Indices?.Count ?? 0}");
            if (response.Indices != null)
            {
                foreach (var node in response.Indices)
                {
                    _output.WriteLine($"Key={node.Key},value={node.Value}");
                }
            }
            _output.WriteLine($"ActiveShards{response.ActiveShards}");
            _output.WriteLine($"ActivePrimaryShards{response.ActivePrimaryShards}");
            _output.WriteLine($"ApiCallDetails{response.ApiCallDetails}");
            _output.WriteLine($"Ϣ{response.ElasticsearchServerError}");
            _output.WriteLine($"Ϣ{string.Join("", response.ElasticsearchWarnings)}");
        }

        /// <summary>
        /// ڵϢ
        /// </summary>
        [Fact]
        public void Node_Test()
        {
            var response = _client.Info();

            Assert.True(response.IsSuccess());

            //Ϣ
            _output.WriteLine($"ڵƣ{response.Name}");
            _output.WriteLine($"Ⱥƣ{response.ClusterName}");
            _output.WriteLine($"ȺUUID{response.ClusterUuid}");
            _output.WriteLine($"ES{response.Tagline}");
            _output.WriteLine($"汾ţ{response.Version.Number}");
            _output.WriteLine($"{response.Version.BuildFlavor}");
            _output.WriteLine($"ͣ{response.Version.BuildType}");
            _output.WriteLine($"ϣ{response.Version.BuildHash}");
            _output.WriteLine($"ڣ{response.Version.BuildDate}");
            _output.WriteLine($"ɿգ{response.Version.BuildSnapshot}");
            _output.WriteLine($"Lucene汾{response.Version.LuceneVersion}");
            _output.WriteLine($"ͼ԰汾{response.Version.MinimumWireCompatibilityVersion}");
            _output.WriteLine($"С԰汾 {response.Version.MinimumIndexCompatibilityVersion}");
            _output.WriteLine($"Ϣ{response.ElasticsearchServerError}");
            _output.WriteLine($"Ϣ{string.Join("", response.ElasticsearchWarnings)}");
        }
    }
}